package com.ORM.relaciones_orm_greendao;

import android.app.Activity;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.Toast;
import com.GreenDAO.relacion1_N.Asignaturas;
import com.GreenDAO.relacion1_N.AsignaturasDao;
import com.GreenDAO.relacion1_N.DaoMaster;
import com.GreenDAO.relacion1_N.DaoMaster.DevOpenHelper;
import com.GreenDAO.relacion1_N.DaoSession;
import com.GreenDAO.relacion1_N.Profesores;
import com.GreenDAO.relacion1_N.ProfesoresDao;

//Ejemplo aplicacin Android con API GreenDAO para establecer relaciones entre tablas (1 : N)
//
//academiaandroid.com
//
//by Jos Antonio Gzquez Rodrguez


public class MainActivity extends Activity {
	
	private static final String TAG = "Error Guardar: ";
	private SQLiteDatabase db;
	private DaoMaster daoMaster;
    private DaoSession daoSession;
    private ProfesoresDao profesoresDao;
    private AsignaturasDao asignaturasDao;
    private EditText txtNombre;
    private EditText txtApellidos;
    private Spinner spinnerCurso;
    private CheckBox matematicas;
    private CheckBox historia;
    private CheckBox lenguaje;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        DevOpenHelper openHelper = new DaoMaster.DevOpenHelper(this, "Matricula", null);
        db = openHelper.getWritableDatabase();
        daoMaster = new DaoMaster(db);
        daoSession = daoMaster.newSession();
        profesoresDao = daoSession.getProfesoresDao();
        asignaturasDao = daoSession.getAsignaturasDao();
        
        txtNombre = (EditText)findViewById(R.id.edNombre);
        txtApellidos = (EditText)findViewById(R.id.edApellidos);
        spinnerCurso = (Spinner)findViewById(R.id.edCurso);
        matematicas = (CheckBox)findViewById(R.id.checkMat);
        historia = (CheckBox)findViewById(R.id.checkHist);
        lenguaje = (CheckBox)findViewById(R.id.checkLeng);
        
        //Array de String con los cursos a los que impartir clase  
        String[] cursos_coleccion = {"1 E.S.O.","2 E.S.O.","3 E.S.O.","4 E.S.O."};
        spinnerCurso.setAdapter(new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item, cursos_coleccion));      
    }

	public void guardarDatos(View view)
	{
		try{
			Asignaturas asignaturas = new Asignaturas();
			Profesores profesores = new Profesores();
			
			String nombre = txtNombre.getText().toString();
			String apellidos = txtApellidos.getText().toString();
			String curso_seleccionado = spinnerCurso.getSelectedItem().toString();
			boolean asig_mat = matematicas.isChecked();
			boolean asig_leng = lenguaje.isChecked();
			boolean asig_hist = historia.isChecked();
			
			//Comprobamos que los campos Nombre y Apellidos no estn vacos
	    	if((nombre.equals("")))
	    	{
	    		Toast.makeText(this, "Debe indicar el nombre del Profesor.", 3000).show();
	    	}
	    	else if(apellidos.equals(""))
	    			{
	    				Toast.makeText(this, "Debe indicar el apellido del Profesor.", 3000).show();
	    			}
			    		else if(curso_seleccionado.equals(""))
			    		{
			    			Toast.makeText(this, "Debe indicar el curso al que impartir clase el Profesor.", 3000).show();
			    		}
	    					//Comprobamos que se ha seleccionado al menos una asignatura
				    		else if((!asig_mat) && (!asig_hist) && (!asig_leng))
				    		{
				    			Toast.makeText(this, "El Profesor debe impartir al menos una asignatura.", 3000).show();
				    		}
	    		
	    	else
	    	{
	    		//Asignamos los valores a los atributos del objeto profesores
		    	profesores.setNombre(nombre);
		    	profesores.setApellidos(apellidos);	
		    	profesores.setCurso(curso_seleccionado);
		    	profesoresDao.insert(profesores);
		    	
		    	//Asignamos los valores a los atributos del objeto asignaturas
		    	asignaturas.setHistoria(asig_hist);
		    	asignaturas.setLenguaje(asig_leng);
		    	asignaturas.setMatemticas(asig_mat);
		    	asignaturas.setIdProfesor(profesores.getId());		    			    	
		    	asignaturasDao.insert(asignaturas);			    			    			    	
		    	
		    	Toast.makeText(this, "Ficha Profesor->\nNombre y Apellidos: " + profesores.getNombre() + " " + profesores.getApellidos() 
		    			+ "\nCurso: " + profesores.getCurso(), 10000).show();
		    	
		    	//Inicializamos los campos una vez se han guardado los datos
		    	txtNombre.setText("");
		    	txtApellidos.setText("");
		    	spinnerCurso.setSelection(0);
		    	historia.setChecked(false);
		    	lenguaje.setChecked(false);
		    	matematicas.setChecked(false);
		    }
			
		}catch(Exception ex)
		{
			Log.d(TAG,ex.getMessage());
			Toast.makeText(this, "No ha sido posible guardar los datos de ficha del Profesor.", 3000).show();
		}
	}
    
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
    
}
